<?php
/*
Plugin Name: WPS AI ChatGPT
Description: Le plugin WPS AI, basé sur l'IA et ChatGPT.
Donate link: https://www.paypal.me/donateWPServeur
Author: WPServeur, NicolasKulka
Author URI: https://wpserveur.net
Version: 1.0
Requires at least: 4.2
Tested up to: 6.0
Domain Path: languages
Text Domain: wps-ai-chatgpt
License: GPLv2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html

*/

// don't load directly
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

// Plugin constants
define( 'WPS_CHATBOT_AI_VERSION', '1.0' );
define( 'WPS_CHATBOT_AI_FOLDER', 'wps-ai-chatgpt' );
define( 'WPS_CHATBOT_AI_BASENAME', plugin_basename( __FILE__ ) );

define( 'WPS_CHATBOT_AI_URL', plugin_dir_url( __FILE__ ) );
define( 'WPS_CHATBOT_AI_DIR', plugin_dir_path( __FILE__ ) );

require_once WPS_CHATBOT_AI_DIR . 'autoload.php';

register_activation_hook( __FILE__, array( '\WPS\WPS_Chatbot_AI\Plugin', 'activate' ) );

if ( ! function_exists( 'plugins_loaded_wps_chatbot_ai_plugin' ) ) {
	add_action( 'plugins_loaded', 'plugins_loaded_wps_chatbot_ai_plugin' );
	function plugins_loaded_wps_chatbot_ai_plugin() {
		\WPS\WPS_Chatbot_AI\Plugin::get_instance();

		load_plugin_textdomain( 'wps-ai-chatgpt', false, basename( rtrim( dirname( __FILE__ ), '/' ) ) . '/languages' );
	}
}

// Enqueue the required scripts
function chatgpt_enqueue_scripts() {
	wp_enqueue_script( 'axios', 'https://cdn.jsdelivr.net/npm/axios/dist/axios.min.js' );
	wp_enqueue_script( 'showdown', '//cdnjs.cloudflare.com/ajax/libs/showdown/1.9.1/showdown.min.js' );
	wp_enqueue_script( 'wps-ai-chatgpt-admin', WPS_CHATBOT_AI_URL . 'assets/js/admin/script.js', array( 'axios', 'showdown', 'wp-blocks', 'wp-editor' ), '1.0', true );
	$api_key = get_theme_mod( 'wpb_chatbot_ai_widget_api_key' );
	wp_localize_script(
		'wps-ai-chatgpt-admin',
		'data_chatbot',
		array(
			'apikey' => $api_key,
			//'url'    => admin_url( 'admin-ajax.php' ),
			//'nonce'  => wp_create_nonce( 'save-chat-nonce' ),
		)
	);
}

add_action( 'admin_enqueue_scripts', 'chatgpt_enqueue_scripts' );

// Add a meta box to the new post screen
function chatgpt_add_meta_box() {
	add_meta_box( 'chatgpt_meta_box', __( 'WPS AI ChatGPT (Article Generator)', 'wps-ai-chatgpt'), 'chatgpt_meta_box_callback', 'post', 'normal', 'high' );
}

add_action( 'add_meta_boxes', 'chatgpt_add_meta_box' );

// Meta box callback function
function chatgpt_meta_box_callback( $post ) {
	wp_nonce_field( 'chatgpt_nonce', 'chatgpt_nonce' );
	?>
    <div id="chatgpt-article-generator">
        <p><b>Nous pouvons créer du contenu pour vous !!!</b><br />Saisissez un sujet, des mots-clés, le nombre de paragraphes ainsi que le style et le ton puis cliquez sur générer.<br />Le texte sera automatiquement copié dans le corps de votre article et vous pourrez le retoucher si nécessaire.</p>

        <div class="wps-autopromo" id="plugin-filter">
            <?php include( WPS_CHATBOT_AI_DIR . '/blocks/pub-ai-wpserveur.php' ); ?>
        </div>

        <div class="form-columns" style="display: flex;justify-content: space-between;">
            <div class="form-column" style="flex-basis: 48%;">
                <p>
                    <label for="chatgpt-language"><?php _e('Language:', 'wps-ai-chatgpt'); ?></label>
                    <select id="chatgpt-language" name="chatgpt-language" class="widefat">
                        <option value="french" selected><?php _e('French', 'wps-ai-chatgpt'); ?></option>
                        <option value="english"><?php _e('English', 'wps-ai-chatgpt'); ?></option>
                    </select>
                </p>
                <p>
                    <label for="chatgpt-title"><?php _e('Subject / Title:', 'wps-ai-chatgpt'); ?></label>
                    <input type="text" id="chatgpt-title" name="chatgpt-title" class="widefat" required/>
                </p>
                <p>
                    <label for="chatgpt-tags"><?php _e('Keywords:', 'wps-ai-chatgpt'); ?></label>
                    <input type="text" id="chatgpt-tags" name="chatgpt-tags" class="widefat"/>
                </p>
            </div>
            <div class="form-column" style="flex-basis: 48%;">
                <p>
                    <label for="chatgpt-nb-paragraph"><?php _e('Number of paragraphs:', 'wps-ai-chatgpt'); ?></label>
                    <input type="number" id="chatgpt-nb-paragraph" name="chatgpt-nb-paragraph" class="widefat" value="3"
                           max="10"/>
                </p>
                <!--<p>
                    <label for="chatgpt-titles"><?php _e('With titles / subtitles:', 'wps-ai-chatgpt'); ?></label>
                    <select id="chatgpt-titles" name="chatgpt-titles" class="widefat">
                        <option value="yes" selected><?php _e('Yes', 'wps-ai-chatgpt'); ?></option>
                        <option value="no"><?php _e('No', 'wps-ai-chatgpt'); ?></option>
                    </select>
                </p>
                <p>
                    <label for="chatgpt-nb-sections"><?php _e('Number of subtitles:', 'wps-ai-chatgpt'); ?></label>
                    <input type="number" id="chatgpt-nb-sections" name="chatgpt-nb-sections" class="widefat"/>
                </p>-->
                <!--<p>
					<label for="chatgpt-introconclusion"><?php _e('Avec intro / conclusion ? :', 'wps-ai-chatgpt'); ?></label>
					<select id="chatgpt-introconclusion" name="chatgpt-introconclusion" class="widefat">
						<option value="yes" selected> _e('Yes', 'wps-ai-chatgpt'); ?></option>
						<option value="no"><?php _e('No', 'wps-ai-chatgpt'); ?></option>
					</select>
				</p>-->
                <p>
                    <label for="chatgpt-styles"><?php _e( 'Style:', 'wps-ai-chatgpt'); ?></label>
                    <select id="chatgpt-styles" name="chatgpt-styles" class="widefat">
                        <option value="Creative" selected><?php _e( 'Creative', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Informative"><?php _e( 'Informative', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Descriptive"><?php _e( 'Descriptive', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Narrative"><?php _e( 'Narrative', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Persuasive"><?php _e( 'Persuasive', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Reflective"><?php _e( 'Reflective', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Argumentative"><?php _e( 'Argumentative', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Analytical"><?php _e( 'Analytical', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Evaluative"><?php _e( 'Evaluative', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Journalistic"><?php _e( 'Journalistic', 'wps-ai-chatgpt' ); ?></option>
                    </select>
                </p>
                <p>
                    <label for="chatgpt-tones"><?php _e( 'Tone:', 'wps-ai-chatgpt'); ?></label>
                    <select id="chatgpt-tones" name="chatgpt-tones" class="widefat">
                        <option value="Neutral"><?php _e( 'Neutral', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Formal"><?php _e( 'Formal', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Assertive"><?php _e( 'Assertive', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Cheerful" selected><?php _e( 'Cheerful', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Humorous"><?php _e( 'Humorous', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Informal"><?php _e( 'Informal', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Inspirational"><?php _e( 'Inspirational', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Professional"><?php _e( 'Professional', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Confluent"><?php _e( 'Confluent', 'wps-ai-chatgpt' ); ?></option>
                        <option value="Emotional"><?php _e( 'Emotional', 'wps-ai-chatgpt' ); ?></option>
                    </select>
                </p>
            </div>
        </div>
        <p>
            <button id="chatgpt-generate" class="button button-primary" style="font-size: 20px;">
                <span id="button-text"><?php _e( 'Generate', 'wps-ai-chatgpt'); ?></span>
            </button>
        </p>
        <div id="spinner-overlay">
            <div class="spinner-container">
                <div class="spinnerwps"></div>
                <div class="spinner-text"><?php _e( 'Please wait 60 to 240 seconds for the generation of the answer.', 'wps-ai-chatgpt'); ?>
                </div>
            </div>
        </div>
        <!--<p>
            <label for="chatgpt-description">Texte généré :</label>
            <textarea id="chatgpt-description" name="chatgpt-description" class="widefat" rows="5"></textarea>
        </p>-->
    </div>

    <style>
        #spinner-overlay {
            position: fixed;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(0, 0, 0, 0.5); /* Couleur de l'arrière-plan semi-transparent */
            display: none;
            align-items: center;
            justify-content: center;
            z-index: 9999; /* Assurez-vous que le spinner est au-dessus des autres éléments */
        }

        .spinnerwps {
            border: 4px solid #f3f3f3; /* Couleur de la bordure */
            border-top: 4px solid #3498db; /* Couleur de la partie supérieure de la bordure */
            border-radius: 50%;
            width: 40px;
            height: 40px;
            animation: spin 2s linear infinite;
        }

        @keyframes spin {
            0% {
                transform: rotate(0deg);
            }
            100% {
                transform: rotate(360deg);
            }
        }

        .spinner-text {
            color: #fff; /* Couleur du texte */
            margin-top: 10px; /* Marge supérieure pour l'espacement */
            text-align: center; /* Centrer le texte */
        }

        .spinner-container {
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: center;
            text-align: center;
            color: #fff; /* Couleur du texte */
            margin-top: 10px; /* Marge supérieure pour l'espacement */
        }
    </style>
	<?php
}